<?php
namespace Blesta\Core\ServiceProviders;

use Pimple\ServiceProviderInterface;
use Pimple\Container;
use Configure;

class Requestor implements ServiceProviderInterface
{
    private $container;

    /**
     * {@inheritdoc}
     */
    public function register(Container $container)
    {
        $this->container = $container;

        // Define all attributes available regarding the requestor
        $this->container->set('requestor', $container->factory(function ($c) {
            // Load the session to retrieve the user information from
            $loader = $c->get('loader');
            $loader->loadComponents($this, ['Session']);

            // Retrieve all of the available user info
            $user_id = $this->Session->read('blesta_id');
            $staff_id = $this->Session->read('blesta_staff_id');
            $ip_address = $this->Session->read('ip');
            $company_id = $this->Session->read('blesta_company_id');

            // Staff or client may be set, but not both (e.g. staff masquerading as a client)
            $client_id = null;
            if (empty($staff_id)) {
                $client_id = $this->Session->read('blesta_client_id');
            }

            // IP address should be set to what's set in the session, if available, otherwise the remote address
            if (empty($ip_address) && !empty($_SERVER['REMOTE_ADDR'])) {
                $ip_address = $_SERVER['REMOTE_ADDR'];
            }

            return (object)[
                'client_id' => ($client_id ? $client_id : null),
                'company_id' => ($company_id ? $company_id : Configure::get('Blesta.company_id')),
                'language' => Configure::get('Blesta.language'),
                'ip_address' => ($ip_address ? $ip_address : null),
                'staff_id' => ($staff_id ? $staff_id : null),
                'user_id' => ($user_id ? $user_id : null)
            ];
        }));
    }
}
